@@ -52,7 +52,7 @@ Copyright (C) 2000 Liam Girdwood <liam@nova-ioe.org>
 * API documentation for libnova is included in the source. It can also be found in this website and an offline tarball is available <A href="http://libnova.sf.net/libnovadocs.tar.gz">here</A>.
 *
 * \section download Download
-* The latest released version of libnova is 0.6.0 and was released on the 26th Jan 2003.
+* The latest released version of libnova is 0.7.0 and was released on the 23rd March 2003.
 * It is available for download <A href="http://sf.net/project/showfiles.php?group_id=57697">here.</A>
 *
 * \section cvs CVS
@@ -1145,7 +1145,7 @@ double get_jupiter_pol_sdiam (double JD);
 * \brief Calculate the time of rise, set and transit for Jupiter.
 * \ingroup jupiter
 */
-int get_jupter_rst (double JD, struct ln_lnlat_posn * observer, struct ln_rst_time * rst);
+int get_jupiter_rst (double JD, struct ln_lnlat_posn * observer, struct ln_rst_time * rst);
 
 /*! \fn void get_jupiter_helio_coords (double JD, struct ln_helio_posn * position);
 * \brief Calculate Jupiter's heliocentric coordinates
@@ -1617,6 +1617,18 @@ double get_lunar_earth_dist (double JD);
 */ 
 double get_lunar_bright_limb (double JD);
 
+/*! \fn double get_lunar_long_asc_node (double JD);
+* \brief Calculate the longitude of the Moon's mean ascending node.
+* \ingroup lunar
+*/ 
+double get_lunar_long_asc_node (double JD);
+
+/*! \fn double get_lunar_long_perigee (double JD);
+* \brief Calculate the longitude of the Moon's mean perigee.
+* \ingroup lunar
+*/ 
+double get_lunar_long_perigee (double JD);
+
 /*! \defgroup elliptic  Elliptic Motion
 *
 * Functions relating to the elliptic motion of bodies.
